@@ -155,7 +155,6 @@ c
 cc      if(IntModel .eq. 'int1') then
 cc        if(pj.fm.p(4)  .lt. Elund) then
 c            h-A collision  Fermi momentum is considered inside
-
       if( ActiveMdl .eq. 'phits') then
          call cphits(pj, ia, iz, TargetXs, a, ntp)
       elseif( ActiveMdl .eq. 'dpmjet3') then
@@ -171,18 +170,15 @@ c            chAcol argment in future ?
      *        ActiveMdl .eq. 'nucrin') then
             call chALund(pj, ia, iz, a, ntp)
       elseif( ActiveMdl .eq. 'ad-hoc') then
-c         elseif(pj.fm.p(4)  .lt. Elund2) then
          call chAcolAdhoc(pj, ia, iz, a, ntp)
-c         elseif(pj.fm.p(4)  .lt. Elund3) then
-      elseif( ActiveMdl .eq. 'fritiof7.02') then
-         if(pj.code .eq. kkaon .and. LundPara(5) .ne. 0) then
-            call chAcolAdhoc(pj, ia, iz, a, ntp)
-         elseif(pj.code .eq. keta) then
-            call chAcolAdhoc(pj, ia, iz, a, ntp)
-         else
-            call chANewLund(pj, ia, iz, a, ntp)
-         endif
-c      elseif(IntModel .eq. 'int2') then
+c      elseif( ActiveMdl .eq. 'fritiof7.02') then
+c         if(pj.code .eq. kkaon .and. LundPara(5) .ne. 0) then
+c            call chAcolAdhoc(pj, ia, iz, a, ntp)
+c         elseif(pj.code .eq. keta) then
+c            call chAcolAdhoc(pj, ia, iz, a, ntp)
+c         else
+c            call chANewLund(pj, ia, iz, a, ntp)
+c         endif
       elseif(ActiveMdl .eq. 'gheisha') then
 c         if(pj.fm.p(4) .lt. Elund) then
          call chAGheisha(pj, ia, iz, a, ntp)
