@@ -236,6 +236,8 @@ c         only hadronic interacting particles are treaed.
       elseif(code .eq. kgnuc ) then
          kf = 1000000000 + abs(chg)*10000 + subcode*10
          kf = sign(kf, chg)
+      elseif( code == keta ) then
+         kf = kfeta
       else
          write(msg, *) 'code, subcode, chg to  ccos2kf=', 
      &      code, subcode, chg  
