@@ -427,6 +427,7 @@ c                is set.
 #include  "Ztrackp.h"
 
       real*8 leng/1.d50/   ! will  be truncated  by ctruncPath
+      integer:: jcon
 
 c     **************************************************
       call ciniSmpIntL   ! init for interaction length sampling
@@ -444,6 +445,16 @@ c
          endif
          call cfixProc
 
+         if( IntInfArray(ProcessNo).process == 'coll' ) then
+!               some of the code can not deal with coll.of sigma 
+!               etc.
+            call cseeColPossible( TrackBefMove.p, jcon)
+            if( jcon == -1) then
+!                  then force to decay
+               call cresetIntInf
+            endif
+         endif
+
          if(.not. Freec .and. Zfirst.pos.depth .eq. 0.) then
             IntInfArray(ProcessNo).length = 0.
             IntInfArray(ProcessNo).thickness = 0.
